Changed Text of Knowledge base button to Help Article
diff --git a/erpnext/support/doctype/issue/issue.js b/erpnext/support/doctype/issue/issue.js
index bef8cb4..c1b76e5 100644
--- a/erpnext/support/doctype/issue/issue.js
+++ b/erpnext/support/doctype/issue/issue.js
@@ -18,12 +18,12 @@
 	},
 
 	timeline_refresh: function(frm) {
-		// create button for "Add to Knowledge Base"
+		// create button for "Help Article"
 		if(frappe.model.can_create('Help Article')) {
 			// Removing Knowledge Base button if exists to avoid multiple occurance
 			frm.timeline.wrapper.find('.comment-header .asset-details .btn-add-to-kb').remove();
-			$('<button class="btn btn-xs btn-default btn-add-to-kb hidden-xs pull-right" style="margin-top: -2px">'+
-				__('Add to Knowledge Base') + '</button>')
+			$('<button class="btn btn-xs btn-link btn-add-to-kb text-muted hidden-xs pull-right">'+
+				__('Help Article') + '</button>')
 				.appendTo(frm.timeline.wrapper.find('.comment-header .asset-details'))
 				.on('click', function() {
 					var content = $(this).parents('.timeline-item:first').find('.timeline-item-content').html();
@@ -18,12 +18,12 @@
 		if(frappe.model.can_create('Help Article')) {
-			// Removing Knowledge Base button if exists to avoid multiple occurance
+			// Removing Help Article button if exists to avoid multiple occurance
 			frm.timeline.wrapper.find('.comment-header .asset-details .btn-add-to-kb').remove();